@@ -4,8 +4,8 @@ class TransformLayer(tf.keras.layers.Layer):
 
     def __init__(self, features_columns, features_list):
         super(TransformLayer, self).__init__()
-        self.sparse_features_list =  feature_list['sparse']
-        self.dense_features_list = feature_list['dense']
+        self.sparse_features_list =  features_list['sparse']
+        self.dense_features_list = features_list['dense']
         self._tra_sp_col, self._tra_nu_col, self._gam_sp_col, self._gam_nu_col = self.get_feature_col(features_columns)
         self.tra_sparse_features = tf.keras.layers.DenseFeatures(self._tra_sp_col)
         self.tra_dense_features = tf.keras.layers.DenseFeatures(self._tra_nu_col)
